@@ -27,10 +27,19 @@ logger = logging.getLogger(__name__)
 
 
 class CustomServiceLoader:
-    """A class to load custom services."""
+    """A class to load custom services.
 
-    def __init__(self, definition_path: str = "resource_definitions") -> None:
-        self.service_definitions_path = os.path.join(pathlib.Path(__file__).parent.absolute(), definition_path)
+    Parameters:
+        definition_path:
+            The absolute path to the resource definition JSON folders. This must mirror the folder structure
+            and JSON schema found in CloudWanderer/boto3.
+    """
+
+    def __init__(self, definition_path: str = None) -> None:
+
+        self.service_definitions_path = definition_path or os.path.join(
+            pathlib.Path(__file__).parent.absolute(), "resource_definitions"
+        )
 
     @memoized_method()
     def get_service_definition(self, service_name: str, type_name: str, api_version: str) -> dict:
@@ -72,9 +81,11 @@ class CustomServiceLoader:
 class MergedServiceLoader(Loader):
     """A class to merge the services from a custom service loader with those of Boto3."""
 
-    def __init__(self) -> None:
-        self.custom_service_loader = CustomServiceLoader()
-        botocore_session = botocore.session.get_session()
+    def __init__(
+        self, custom_service_loader: CustomServiceLoader = None, botocore_session: botocore.session.Session = None
+    ) -> None:
+        self.custom_service_loader = custom_service_loader or CustomServiceLoader()
+        botocore_session = botocore_session or botocore.session.get_session()
         self.botocore_loader = botocore_session.get_component("data_loader")
         boto3_data_path = os.path.join(os.path.dirname(boto3.__file__), "data")
         self.botocore_loader.search_paths.append(boto3_data_path)
@@ -82,7 +93,7 @@ class MergedServiceLoader(Loader):
     def list_available_services(self, type_name: str = "resources-1") -> List[str]:
         _ = type_name
         """Return a list of service names that can be loaded."""
-        return list(set(self.cloudwanderer_available_services + self.boto3_available_services))
+        return sorted(list(set(self.cloudwanderer_available_services + self.boto3_available_services)))
 
     def determine_latest_version(self, service_name: str, type_name: str) -> str:
         return max(self.list_api_versions(service_name, type_name))
